@@ -8,6 +8,7 @@
 
 #import "SUApplicationInfo.h"
 #import "SUBundleIcon.h"
+#import "SUHost.h"
 
 @implementation SUApplicationInfo
 
@@ -16,16 +17,16 @@
     return (application.activationPolicy == NSApplicationActivationPolicyAccessory);
 }
 
-+ (NSImage *)bestIconForBundle:(NSBundle *)bundle
++ (NSImage *)bestIconForHost:(SUHost *)host
 {
-    NSURL *iconURL = [SUBundleIcon iconURLForBundle:bundle];
+    NSURL *iconURL = [SUBundleIcon iconURLForHost:host];
     
     NSImage *icon = (iconURL == nil) ? nil : [[NSImage alloc] initWithContentsOfURL:iconURL];
     // Use a default icon if none is defined.
     if (!icon) {
         // this asumption may not be correct (eg. even though we're not the main bundle, it could be still be a regular app)
         // but still better than nothing if no icon was included
-        BOOL isMainBundle = (bundle == [NSBundle mainBundle]);
+        BOOL isMainBundle = [host.bundle isEqualTo:[NSBundle mainBundle]];
         
         NSString *fileType = isMainBundle ? (__bridge NSString *)kUTTypeApplication : (__bridge NSString *)kUTTypeBundle;
         icon = [[NSWorkspace sharedWorkspace] iconForFileType:fileType];
