@@ -143,7 +143,11 @@ static BOOL SUMakeRefFromURL(NSURL *url, FSRef *ref, NSError **error) {
     return YES;
 }
 
-- (BOOL)_authorizeAndExecuteCommand:(char *)command sourcePath:(char *)sourcePath destinationPath:(char *)destinationPath error:(NSError * __autoreleasing *)error
+- (BOOL)_authorizeAndExecuteCommand:(char *)command sourcePath:(char *)sourcePath destinationPath:(char *)destinationPath error:(NSError * __autoreleasing *)error {
+    return [self _authorizeAndExecuteCommand:command sourcePath:sourcePath destinationPath:destinationPath lineCallback:nil error:error];
+}
+
+- (BOOL)_authorizeAndExecuteCommand:(char *)command sourcePath:(char *)sourcePath destinationPath:(char *)destinationPath lineCallback:(void(^)(NSString*))lineCallback error:(NSError * __autoreleasing *)error
 {
     NSError *acquireError = nil;
     if (![self _acquireAuthorizationWithError:&acquireError]) {
@@ -166,10 +170,14 @@ static BOOL SUMakeRefFromURL(NSURL *url, FSRef *ref, NSError **error) {
     FILE *pipe = NULL;
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wdeprecated-declarations"
-    if (AuthorizationExecuteWithPrivileges(_auth, toolPath, kAuthorizationFlagDefaults, arguments, &pipe) != errAuthorizationSuccess) {
+    OSStatus runStatus = AuthorizationExecuteWithPrivileges(_auth, toolPath, kAuthorizationFlagDefaults, arguments, &pipe);
+    if (runStatus != errAuthorizationSuccess) {
 #pragma clang diagnostic pop
         if (error != NULL) {
-            *error = [NSError errorWithDomain:SUSparkleErrorDomain code:SUAuthenticationFailure userInfo:@{ NSLocalizedDescriptionKey:@"Failed to run authorization tool." }];
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wcstring-format-directive"
+            *error = [NSError errorWithDomain:SUSparkleErrorDomain code:SUAuthenticationFailure userInfo:@{ NSLocalizedDescriptionKey:[NSString stringWithFormat:@"Failed to run authorization tool %s (error code %d).", toolPath, (int)runStatus] }];
+#pragma clang diagnostic pop
         }
         return NO;
     }
@@ -183,6 +191,11 @@ static BOOL SUMakeRefFromURL(NSURL *url, FSRef *ref, NSError **error) {
         return NO;
     }
     
+    if (lineCallback) {
+        NSFileHandle *pipeHandle = [[NSFileHandle alloc] initWithFileDescriptor:fileno(pipe) closeOnDealloc:NO];
+        [self parseLines:pipeHandle lineCallback:lineCallback];
+    }
+
     pid_t childPid = (int32_t)CFSwapInt32LittleToHost(pidData);
     int status = 0;
     
@@ -203,6 +216,28 @@ static BOOL SUMakeRefFromURL(NSURL *url, FSRef *ref, NSError **error) {
     return YES;
 }
 
+- (void)parseLines:(NSFileHandle *)pipeHandle lineCallback:(void(^)(NSString *))lineCallback {
+    __block NSMutableData *line = [NSMutableData new];
+    pipeHandle.readabilityHandler = ^(NSFileHandle *handle){
+        NSData *data = handle.availableData;
+        NSUInteger length = data.length;
+        if (!length) {
+            return;
+        }
+        const char *bytes = data.bytes;
+        for(NSUInteger i = 0; i < length; i++) {
+            if (bytes[i] == '\n') {
+                NSData *dataToEOL = [data subdataWithRange:NSMakeRange(0, i)];
+                [line appendData:dataToEOL];
+                NSString *fullLine = [[NSString alloc] initWithData:line encoding:NSUTF8StringEncoding];
+                lineCallback(fullLine);
+                line = [[data subdataWithRange:NSMakeRange(i+1, length-i-1)] mutableCopy];
+                break;
+            }
+        }
+    };
+}
+
 - (void)dealloc
 {
     if (_auth != NULL) {
@@ -923,7 +958,7 @@ static BOOL SUMakeRefFromURL(NSURL *url, FSRef *ref, NSError **error) {
 }
 
 // Unlike other methods, authorization is required to execute this method successfully
-- (BOOL)executePackageAtURL:(NSURL *)packageURL error:(NSError * __autoreleasing *)error
+- (BOOL)executePackageAtURL:(NSURL *)packageURL progressBlock:(void(^)(double))progressBlock error:(NSError * __autoreleasing *)error
 {
     if (![self _itemExistsAtURL:packageURL]) {
         if (error != NULL) {
@@ -941,7 +976,11 @@ static BOOL SUMakeRefFromURL(NSURL *url, FSRef *ref, NSError **error) {
     }
     
     NSError *executeError = nil;
-    BOOL success = [self _authorizeAndExecuteCommand:SUFileOpInstallCommand sourcePath:path destinationPath:NULL error:&executeError];
+    BOOL success = [self _authorizeAndExecuteCommand:SUFileOpInstallCommand sourcePath:path destinationPath:NULL lineCallback:^(NSString *line){
+        if ([line hasPrefix:@"installer:%"]) {
+            progressBlock([[line substringFromIndex:11] doubleValue]/100.0);
+        }
+    } error:&executeError];
     
     if (!success && error != NULL) {
         NSString* errorMessage = @"Failed to execute package installer.";
