@@ -21,7 +21,7 @@ NS_ASSUME_NONNULL_BEGIN
 // Any installation work after the user application has been terminated. This is where the final installation work can be done.
 // After this stage is done, the user application may be relaunched.
 // Should be able to be called from non-main thread
-- (BOOL)performFinalInstallation:(NSError **)error;
+- (BOOL)performFinalInstallationProgressBlock:(nullable void(^)(double))cb error:(NSError **)error;
 
 // Indicates whether or not this installer can install the update silently in the background, without hindering the user
 // Should be thread safe
