@@ -12,13 +12,17 @@
 
 @interface SUScheduledUpdateDriver ()
 
-@property (assign) BOOL showErrors;
-
 @end
 
 @implementation SUScheduledUpdateDriver
 
-@synthesize showErrors;
+- (instancetype)initWithUpdater:(id<SUUpdaterPrivate>)anUpdater
+{
+    if ((self = [super initWithUpdater:anUpdater])) {
+        self.showErrors = NO;
+    }
+    return self;
+}
 
 - (void)didFindValidUpdate
 {
@@ -39,21 +43,8 @@
     [self abortUpdate]; // Don't tell the user that no update was found; this was a scheduled update.
 }
 
-- (void)abortUpdateWithError:(NSError *)error
-{
-    if (self.showErrors) {
-        [super abortUpdateWithError:error];
-    } else {
-        // Call delegate separately here because otherwise it won't know we stopped.
-        // Normally this gets called by the superclass
-        id<SUUpdaterPrivate> updater = self.updater;
-        id<SUUpdaterDelegate> updaterDelegate = [updater delegate];
-        if ([updaterDelegate respondsToSelector:@selector(updater:didAbortWithError:)]) {
-            [updaterDelegate updater:self.updater didAbortWithError:error];
-        }
-
-        [self abortUpdate];
-    }
+- (BOOL)shouldDisableKeyboardShortcutForInstallButton {
+    return YES;
 }
 
 @end
