@@ -56,9 +56,17 @@ NSString *const SUUpdateDriverFinishedNotification = @"SUUpdateDriverFinished";
     return NO;
 }
 
+-(BOOL)downloadsAppcastInBackground {
+    return YES;
+}
+
+-(BOOL)downloadsUpdatesInBackground {
+    return NO;
+}
+
 - (void)showAlert:(NSAlert *)alert {
     // Only UI-based subclass shows the actual alert
-    SULog(@"ALERT: %@\n%@", alert.messageText, alert.informativeText);
+    SULog(SULogLevelDefault, @"ALERT: %@\n%@", alert.messageText, alert.informativeText);
 }
 
 @end
